import os
from flask import send_file

TEMPLATE_FOLDER = os.path.normpath(
    os.path.join(os.path.dirname(__file__), 'templates')
)


def send_static(filename):
    filepath = os.path.join(TEMPLATE_FOLDER, filename)
    return send_file(filepath)



import sys
import argparse
import subprocess


def parse_args():
    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers()

    # define run parser
    run_parser = subparsers.add_parser('run')
    run_parser.set_defaults(action='run')
    run_parser.add_argument(
        '--host', type=str, default='localhost', help='Server address')
    run_parser.add_argument(
        '-p', '--port', type=int, default=5000, help='Server port')
    run_parser.add_argument(
        '-b', '--bind', help='Server binding to format <HOST>:<PORT> (e.g 0.0.0.0:80)')

    args = parser.parse_args()
    if not hasattr(args, 'action'):
        parser.print_help()
        sys.exit(1)

    return args


def main():
    args = parse_args()

    if args.action == 'run':
        if args.bind is None:
            address = '%s:%s' % (args.host, args.port)
        else:
            address = args.bind

        subprocess.call(['gunicorn', '-b', address, 'team_mates.server:app'])


if __name__ == '__main__':
    main()



from flask import Flask, jsonify, redirect
from .helpers import send_static
import werkzeug.exceptions as httperror

app = Flask(__name__)


@app.route('/')
def index():
    return send_static('index.html')


@app.route('/<path:path>')
def serve_file(path):
    try:
        return send_static(path)
    except httperror.NotFound as e:
        return send_static('index.html')


@app.route('/api/projects')
def projects_data():
    return str([])


@app.route('/api/<path:path>')
def api_404_handler(path):
    return jsonify({
        "message": "Route not found."
    }), 404


if __name__ == '__main__':
    app.run(debug=True)



import platform
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

# select os specific dependencies
operating_system = platform.system()
if operating_system == 'Windows':
    raise OSError("This module has no support for windows yet.")
elif operating_system == 'Linux':
    WSGI_SERVER = 'gunicorn'

setuptools.setup(
    name="team_mates",
    version="0.0.5",
    author="Sylvan LE DEUNFF",
    author_email="sylvan.ledeunff@gmail.com",
    description="A library to analyze team mates contributions to projects.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/team-mates",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],

    packages=setuptools.find_packages(exclude=("frontend",)),
    include_package_data=True,

    entry_points={
        'console_scripts': [
            'team-mates=team_mates.__main__:main'
        ],
    },
    install_requires=[
        'flask',
        WSGI_SERVER
    ],
    python_requires='>=3.6',
)
